
%global base_name   daemon
%global short_name  commons-%{base_name}

Name:           apache-%{short_name}
Version:        1.0.15
Release:        %mkrel 15
Summary:        Defines API to support an alternative invocation mechanism
License:        ASL 2.0
Group:          Development/Java
URL:            http://commons.apache.org/%{base_name}
Source0:        http://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Patch1:         apache-commons-daemon-JAVA_OS.patch
# backport from https://fisheye6.atlassian.com/changelog/commons?cs=1458896
Patch2:         apache-commons-daemon-secondary.patch
# backport from http://svn.apache.org/viewvc?view=revision&revision=1533345
# https://issues.apache.org/jira/browse/DAEMON-308
Patch3:         apache-commons-daemon-aarch64.patch
BuildRequires:  maven-local
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  apache-commons-parent
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  xmlto


%description
The scope of this package is to define an API in line with the current
Java Platform APIs to support an alternative invocation mechanism
which could be used instead of the public static void main(String[])
method.  This specification covers the behavior and life cycle of what
we define as Java daemons, or, in other words, non interactive
Java applications.

%package        jsvc
Summary:        Java daemon launcher
Group:          Development/Java
Provides:       jsvc = 1:%{version}-%{release}

%description    jsvc
%{summary}.

%package        javadoc
Summary:        API documentation for %{name}
Group:          Documentation
Requires:       jpackage-utils
BuildArch:      noarch

%description    javadoc
%{summary}.


%prep
%setup -q -n %{short_name}-%{version}-src
%patch1 -p1 -b .java_os
%patch2 -p1 -b .secondary
%patch3 -p1 -b .aarch64

# remove java binaries from sources
rm -rf src/samples/build/

chmod 644 src/samples/*
cd src/native/unix
xmlto man man/jsvc.1.xml


%build

# build native jsvc
pushd src/native/unix
%configure --with-java=%{java_home}
# this is here because 1.0.2 archive contains old *.o
make clean
make %{?_smp_mflags}
popd

# build jars
%mvn_file  : %{short_name} %{name}
%mvn_alias : org.apache.commons:%{short_name}
%mvn_build


%install
# install native jsvc
install -Dpm 755 src/native/unix/jsvc $RPM_BUILD_ROOT%{_bindir}/jsvc
install -Dpm 644 src/native/unix/jsvc.1 $RPM_BUILD_ROOT%{_mandir}/man1/jsvc.1

%mvn_install


%files -f .mfiles
%doc LICENSE.txt PROPOSAL.html NOTICE.txt RELEASE-NOTES.txt src/samples
%doc src/docs/*


%files jsvc
%doc LICENSE.txt NOTICE.txt
%{_bindir}/jsvc
%{_mandir}/man1/jsvc.1*


%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt NOTICE.txt




%changelog
* Wed May 17 2017 neoclust <neoclust> 1.0.15-15.mga6
+ Revision: 1102470
- Rebuild against fixed apache-parent

* Wed Mar 02 2016 neoclust <neoclust> 1.0.15-14.mga6
+ Revision: 982005
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.0.15-13.mga6
+ Revision: 977189
- Rebuild on current stack

* Tue Feb 23 2016 neoclust <neoclust> 1.0.15-12.mga6
+ Revision: 977171
- First rebuild of the java stack
- sync package apache-commons-daemon with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sun Jan 11 2015 pterjan <pterjan> 1.0.15-5.mga5
+ Revision: 809898
- Sync with Fedora 21

  + dmorgan <dmorgan>
    - Restore from Obsolete

  + sander85 <sander85>
    - Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 1.0.15-4.mga5
+ Revision: 748079
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.15-3.mga5
+ Revision: 677798
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.0.15-2.mga4
+ Revision: 529793
- Mageia 4 Mass Rebuild

* Fri Jul 12 2013 dmorgan <dmorgan> 1.0.15-1.mga4
+ Revision: 453403
- New version

* Tue Jul 09 2013 dmorgan <dmorgan> 1.0.11-1.mga4
+ Revision: 451834
- Update to upstream version 1.0.11

* Fri Jan 11 2013 umeabot <umeabot> 1.0.10-4.mga3
+ Revision: 345690
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 13 2012 dmorgan <dmorgan> 1.0.10-3.mga3
+ Revision: 293265
- add s390x as known arch

* Mon Jul 16 2012 dmorgan <dmorgan> 1.0.10-2.mga3
+ Revision: 271288
- $supported_os and $JAVA_OS in configure do not always match
- on arches that override supported_os to be the arch we can not find headers

* Mon Jul 09 2012 dmorgan <dmorgan> 1.0.10-1.mga3
+ Revision: 269043
- New version 1.0.10
- Update to latest upstream (1.0.8)
- Drop s390/ppc patches (upstream seems to already include them)

* Tue Sep 06 2011 tv <tv> 1.0.7-1.mga2
+ Revision: 139176
- new release

  + dmorgan <dmorgan>
    - Update to latest upstream (1.0.6)
    - Cleanups according to new guidelines

* Tue Jul 19 2011 dmorgan <dmorgan> 1.0.5-5.mga2
+ Revision: 126799
- Use mvn-rpmbuild instead of mvn-local (changes in maven)

* Wed Apr 27 2011 dmorgan <dmorgan> 1.0.5-4.mga1
+ Revision: 92229
- Rebuild after bootstrapping
- imported package apache-commons-daemon


* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Feb  1 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.5-2
- Fix bug 669259 (execve warning segfault)

* Tue Jan 18 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.5-1
- Update to latest version
- Use maven 3 to build
- Versionless jars & javadocs
- Use apache-commons-parent for BR

* Tue Oct 26 2010 Chris Spike <chris.spike@arcor.de> 1.0.4-2
- Added fix to remove java binaries from sources

* Tue Oct 26 2010 Chris Spike <chris.spike@arcor.de> 1.0.4-1
- Updated to 1.0.4

* Fri Oct 22 2010 Chris Spike <chris.spike@arcor.de> 1.0.3-1
- Updated to 1.0.3
- Cleaned up BRs

* Thu Jul  8 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.2-4
- Add license to javadoc subpackage

* Fri Jun  4 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.2-3
- Make javadoc subpackage noarch

* Tue Jun  1 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.2-2
- Fix add_to_maven_depmap call
- Added depmap for old groupId
- Unified use of `install`

* Wed May 12 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.0.2-1
- Rename and rebase to apache-commons-daemon
- Get rid of gcj, native conditional compilation
- Build with maven
- Update patches to cleanly apply on new version, remove unneeded
- Clean up whole spec

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.0.1-8.8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Mar 03 2009 Karsten Hopp <karsten@redhat.com> 1.0.1-7.8
- ppc needs a similar patch

* Tue Mar 03 2009 Karsten Hopp <karsten@redhat.com> 1.0.1-7.7
- add configure patch for s390x

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.0.1-7.6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul  9 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1:1.0.1-6.6
- drop repotag

* Fri Feb 08 2008 Permaine Cheung <pcheung@redhat.com> - 1:1.0.1-6jpp.5
- Add configure patch for ia64 from Doug Chapman

* Mon Sep 24 2007 Permaine Cheung <pcheung@redhat.com> - 1:1.0.1-6jpp.4
- Add execve path warning patch from James Ralston
